@@ -24,12 +24,11 @@ class XgbWrapper(object):
         num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
         early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
         verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
-        try:
-            del self.params['num_boost_round']
-            del self.params['early_stopping_rounds']
-            del self.params['verbose_eval']
-        except:
-            pass
+
+        for del_col in del_cols:
+            if del_col in self.params.keys():
+                del self.params[del_col]
+        
         self.clf = xgb.train(params=self.params, 
                       dtrain=xgb_train,
                       evals=[(xgb_train, 'train'), (xgb_valid, 'valid')],
@@ -58,12 +57,10 @@ class XgbWrapper(object):
             kf = StratifiedKFold(n_splits = nfolds, shuffle=True, random_state=seed)
         
         
-        try:
-            del params['num_boost_round']
-            del params['early_stopping_rounds']
-            del params['verbose_eval']
-        except:
-            pass
+        for del_col in del_cols:
+            if del_col in params.keys():
+                del params[del_col]
+        
         
         history = xgb.cv(params, data_train, 
              num_boost_round=num_boost_round, 
@@ -99,12 +96,10 @@ class LightGBMWrapper(object):
         early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
         verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
 
-        try:
-            del self.params['num_boost_round']
-            del self.params['early_stopping_rounds']
-            del self.params['verbose_eval']
-        except:
-            pass
+        for del_col in del_cols:
+            if del_col in self.params.keys():
+                del self.params[del_col]
+        
         
         self.clf = lgb.train(params=self.params, 
                          train_set=lgb_train,
@@ -135,12 +130,10 @@ class LightGBMWrapper(object):
         else:
             kf = StratifiedKFold(n_splits = nfolds, shuffle=True, random_state=seed)
         
-        try:
-            del params['num_boost_round']
-            del params['early_stopping_rounds']
-            del params['verbose_eval']
-        except:
-            pass
+        for del_col in del_cols:
+            if del_col in params.keys():
+                del params[del_col]
+        
         
         history = lgb.cv(params, data_train, 
              num_boost_round=num_boost_round, 
@@ -173,12 +166,10 @@ class CatboostWrapper(object):
         num_boost_round = self.params['num_boost_round'] if 'num_boost_round' in self.params.keys() else num_boost_round
         early_stopping_rounds = self.params['early_stopping_rounds'] if 'early_stopping_rounds' in self.params.keys() else early_stopping_rounds
         verbose_eval = self.params['verbose_eval'] if 'verbose_eval' in self.params.keys() else verbose_eval
-        try:
-            del self.params['num_boost_round']
-            del self.params['early_stopping_rounds']
-            del self.params['verbose_eval']
-        except:
-            pass
+
+        for del_col in del_cols:
+            if del_col in self.params.keys():
+                del self.params[del_col]
         
         self.clf = cb.train(dtrain=cb_train, 
                             params=self.params, 
